readHTSeqFile: Parse HTSeq output to tibble

readHTSeqFileR Documentation

Parse HTSeq output to tibble

Description

parse the htseq output as a tibble with columns (feature, sample). This code is copied from the National Cancer Institute GenomicDataCommons

Usage

readHTSeqFile(htseq_filename, samplename = "sample")

Arguments

htseq_filename

filepath to htseq output

samplename

in the legacy pipeline, the fastqFileName with .fastq.gz replaced with _read_count.tsv

Value

a dataframe with columns feature, 'sample'

References

GenomicDataCommons::readHTSeqFile


BrentLab/brentlabRnaSeqTools documentation built on Aug. 20, 2023, 9:22 a.m.