| readHTSeqFile | R Documentation |
parse the htseq output as a tibble with columns (feature, sample). This code is copied from the National Cancer Institute GenomicDataCommons
readHTSeqFile(htseq_filename, samplename = "sample")
htseq_filename |
filepath to htseq output |
samplename |
in the legacy pipeline, the fastqFileName with .fastq.gz replaced with _read_count.tsv |
a dataframe with columns feature, 'sample'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.